# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .alert_muting_rule import *
from .dashboard import *
from .dashboard_group import *
from .data_link import *
from .detector import *
from .event_feed_chart import *
from .get_aws_services import *
from .get_azure_services import *
from .get_dimension_values import *
from .heatmap_chart import *
from .list_chart import *
from .org_token import *
from .provider import *
from .single_value_chart import *
from .team import *
from .text_chart import *
from .time_chart import *
from .webhook_integration import *
from ._inputs import *
from . import outputs

# Make subpackages available:
from . import (
    aws,
    azure,
    config,
    gcp,
    jira,
    opsgenie,
    pagerduty,
    slack,
    victorops,
)

def _register_module():
    import pulumi
    from . import _utilities


    class Module(pulumi.runtime.ResourceModule):
        _version = _utilities.get_semver_version()

        def version(self):
            return Module._version

        def construct(self, name: str, typ: str, urn: str) -> pulumi.Resource:
            if typ == "signalfx:index/alertMutingRule:AlertMutingRule":
                return AlertMutingRule(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "signalfx:index/dashboard:Dashboard":
                return Dashboard(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "signalfx:index/dashboardGroup:DashboardGroup":
                return DashboardGroup(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "signalfx:index/dataLink:DataLink":
                return DataLink(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "signalfx:index/detector:Detector":
                return Detector(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "signalfx:index/eventFeedChart:EventFeedChart":
                return EventFeedChart(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "signalfx:index/heatmapChart:HeatmapChart":
                return HeatmapChart(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "signalfx:index/listChart:ListChart":
                return ListChart(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "signalfx:index/orgToken:OrgToken":
                return OrgToken(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "signalfx:index/singleValueChart:SingleValueChart":
                return SingleValueChart(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "signalfx:index/team:Team":
                return Team(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "signalfx:index/textChart:TextChart":
                return TextChart(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "signalfx:index/timeChart:TimeChart":
                return TimeChart(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "signalfx:index/webhookIntegration:WebhookIntegration":
                return WebhookIntegration(name, pulumi.ResourceOptions(urn=urn))
            else:
                raise Exception(f"unknown resource type {typ}")


    _module_instance = Module()
    pulumi.runtime.register_resource_module("signalfx", "index/alertMutingRule", _module_instance)
    pulumi.runtime.register_resource_module("signalfx", "index/dashboard", _module_instance)
    pulumi.runtime.register_resource_module("signalfx", "index/dashboardGroup", _module_instance)
    pulumi.runtime.register_resource_module("signalfx", "index/dataLink", _module_instance)
    pulumi.runtime.register_resource_module("signalfx", "index/detector", _module_instance)
    pulumi.runtime.register_resource_module("signalfx", "index/eventFeedChart", _module_instance)
    pulumi.runtime.register_resource_module("signalfx", "index/heatmapChart", _module_instance)
    pulumi.runtime.register_resource_module("signalfx", "index/listChart", _module_instance)
    pulumi.runtime.register_resource_module("signalfx", "index/orgToken", _module_instance)
    pulumi.runtime.register_resource_module("signalfx", "index/singleValueChart", _module_instance)
    pulumi.runtime.register_resource_module("signalfx", "index/team", _module_instance)
    pulumi.runtime.register_resource_module("signalfx", "index/textChart", _module_instance)
    pulumi.runtime.register_resource_module("signalfx", "index/timeChart", _module_instance)
    pulumi.runtime.register_resource_module("signalfx", "index/webhookIntegration", _module_instance)


    class Package(pulumi.runtime.ResourcePackage):
        _version = _utilities.get_semver_version()

        def version(self):
            return Package._version

        def construct_provider(self, name: str, typ: str, urn: str) -> pulumi.ProviderResource:
            if typ != "pulumi:providers:signalfx":
                raise Exception(f"unknown provider type {typ}")
            return Provider(name, pulumi.ResourceOptions(urn=urn))


    pulumi.runtime.register_resource_package("signalfx", Package())

_register_module()



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables

__all__ = [
    'GetDimensionValuesResult',
    'AwaitableGetDimensionValuesResult',
    'get_dimension_values',
]

@pulumi.output_type
class GetDimensionValuesResult:
    """
    A collection of values returned by getDimensionValues.
    """
    def __init__(__self__, id=None, query=None, values=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if query and not isinstance(query, str):
            raise TypeError("Expected argument 'query' to be a str")
        pulumi.set(__self__, "query", query)
        if values and not isinstance(values, list):
            raise TypeError("Expected argument 'values' to be a list")
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def query(self) -> str:
        return pulumi.get(self, "query")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")


class AwaitableGetDimensionValuesResult(GetDimensionValuesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDimensionValuesResult(
            id=self.id,
            query=self.query,
            values=self.values)


def get_dimension_values(query: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDimensionValuesResult:
    """
    Use this data source to get a list of dimension values matching the provided query.

    > **NOTE** This data source only allows 1000 values, as it's kinda nuts to make anything with `for_each` that big in SignalFx. This is negotiable.
    """
    __args__ = dict()
    __args__['query'] = query
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('signalfx:index/getDimensionValues:getDimensionValues', __args__, opts=opts, typ=GetDimensionValuesResult).value

    return AwaitableGetDimensionValuesResult(
        id=__ret__.id,
        query=__ret__.query,
        values=__ret__.values)
